@@ -20,7 +20,6 @@
 
 #include "networkstatus.h"
 #include "uiutils.h"
-
 #include <QDBusConnection>
 
 #include <NetworkManagerQt/ActiveConnection>
@@ -61,6 +60,9 @@ NetworkStatus::SortedConnectionType NetworkStatus::connectionTypeToSortedType(Ne
         case NetworkManager::ConnectionSettings::Wireless:
             return NetworkStatus::Wireless;
             break;
+        case NetworkManager::ConnectionSettings::WireGuard:
+            return NetworkStatus::Wireguard;
+            break;
         default:
             return NetworkStatus::Other;
             break;
@@ -93,7 +95,7 @@ QString NetworkStatus::networkStatus() const
 
 void NetworkStatus::activeConnectionsChanged()
 {
-    Q_FOREACH (const NetworkManager::ActiveConnection::Ptr & active, NetworkManager::activeConnections()) {
+    for (const NetworkManager::ActiveConnection::Ptr & active : NetworkManager::activeConnections()) {
         connect(active.data(), &NetworkManager::ActiveConnection::default4Changed, this, &NetworkStatus::defaultChanged, Qt::UniqueConnection);
         connect(active.data(), &NetworkManager::ActiveConnection::default6Changed, this, &NetworkStatus::defaultChanged, Qt::UniqueConnection);
         connect(active.data(), &NetworkManager::ActiveConnection::stateChanged, this, &NetworkStatus::changeActiveConnections);
@@ -165,15 +167,12 @@ void NetworkStatus::changeActiveConnections()
         return NetworkStatus::connectionTypeToSortedType(left->type()) < NetworkStatus::connectionTypeToSortedType(right->type());
     });
 
-    Q_FOREACH (const NetworkManager::ActiveConnection::Ptr & active, activeConnectionList) {
+    for (const NetworkManager::ActiveConnection::Ptr &active : activeConnectionList) {
         if (!active->devices().isEmpty() && UiUtils::isConnectionTypeSupported(active->type())) {
 
             NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(active->devices().first());
-#if NM_CHECK_VERSION(0, 9, 10)
-            if (device && device->type() != NetworkManager::Device::Generic && device->type() <= NetworkManager::Device::Team) {
-#else
-            if (device) {
-#endif
+            if (device && ((device->type() != NetworkManager::Device::Generic && device->type() <= NetworkManager::Device::Team)
+                           || device->type() == 29)) {  // TODO: Change to WireGuard enum value when it is added
                 bool connecting = false;
                 bool connected = false;
                 QString conType;
@@ -202,6 +201,11 @@ void NetworkStatus::changeActiveConnections()
                     }
                 }
 
+                if (active->type() == NetworkManager::ConnectionSettings::ConnectionType::WireGuard) {
+                    conType = i18n("WireGuard");
+                    connected = true;
+                }
+
                 NetworkManager::Connection::Ptr connection = active->connection();
                 if (connecting) {
                     status = i18n("Connecting to %1", connection->name());
