@@ -29,7 +29,6 @@
 #include <QDialog>
 #include <QVBoxLayout>
 #include <QDialogButtonBox>
-
 #include <KUser>
 #include <KAcceleratorManager>
 #include <KLocalizedString>
@@ -99,7 +98,7 @@ void ConnectionWidget::loadConfig(const NetworkManager::ConnectionSettings::Ptr
     const QStringList secondaries = settings->secondaries();
     const QStringList vpnKeys = vpnConnections().keys();
     if (!secondaries.isEmpty() && !vpnKeys.isEmpty()) {
-        Q_FOREACH (const QString & vpnKey, vpnKeys) {
+        for (const QString &vpnKey : vpnKeys) {
             if (secondaries.contains(vpnKey)) {
                 m_widget->vpnCombobox->setCurrentIndex(m_widget->vpnCombobox->findData(vpnKey));
                 m_widget->autoconnectVpn->setChecked(true);
@@ -177,9 +176,10 @@ NMStringMap ConnectionWidget::vpnConnections() const
     NetworkManager::Connection::List list = NetworkManager::listConnections();
     NMStringMap result;
 
-    Q_FOREACH (const NetworkManager::Connection::Ptr & conn, list) {
+    for (const NetworkManager::Connection::Ptr &conn : list) {
         NetworkManager::ConnectionSettings::Ptr conSet = conn->settings();
-        if (conSet->connectionType() == NetworkManager::ConnectionSettings::Vpn) {
+        if (conSet->connectionType() == NetworkManager::ConnectionSettings::Vpn
+            || conSet->connectionType() == NetworkManager::ConnectionSettings::WireGuard) {
             // qCDebug(PLASMA_NM) << "Found VPN" << conSet->id() << conSet->uuid();
             result.insert(conSet->uuid(), conSet->id());
         }
